#[non_exhaustive]pub struct BridgeVlanGlobalOptions { /* private fields */ }Expand description
Bridge-global per-VLAN options, as read back from the kernel.
Returned by Connection::get_bridge_vlan_global_options. Fields
are Option because the kernel only reports options relevant to
the running configuration. The struct is #[non_exhaustive] so new
kernel options can be added without a breaking change.
See BridgeVlanGlobalOptionsBuilder for the not modelled
attributes.
Implementations
Sourceimpl BridgeVlanGlobalOptions
impl BridgeVlanGlobalOptions
Sourcepub fn mcast_snooping(&self) -> Option<bool>
pub fn mcast_snooping(&self) -> Option<bool>
Whether per-VLAN multicast snooping is enabled.
Sourcepub fn mcast_querier(&self) -> Option<bool>
pub fn mcast_querier(&self) -> Option<bool>
Whether the per-VLAN multicast querier is enabled.
Sourcepub fn mcast_igmp_version(&self) -> Option<u8>
pub fn mcast_igmp_version(&self) -> Option<u8>
IGMP query version.
Sourcepub fn mcast_mld_version(&self) -> Option<u8>
pub fn mcast_mld_version(&self) -> Option<u8>
MLD query version.
Sourcepub fn mcast_last_member_count(&self) -> Option<u32>
pub fn mcast_last_member_count(&self) -> Option<u32>
Last-member query count.
Sourcepub fn mcast_startup_query_count(&self) -> Option<u32>
pub fn mcast_startup_query_count(&self) -> Option<u32>
Startup query count.
Sourcepub fn mcast_last_member_interval(&self) -> Option<u64>
pub fn mcast_last_member_interval(&self) -> Option<u64>
Last-member query interval (centiseconds).
Sourcepub fn mcast_membership_interval(&self) -> Option<u64>
pub fn mcast_membership_interval(&self) -> Option<u64>
Membership interval (centiseconds).
Sourcepub fn mcast_querier_interval(&self) -> Option<u64>
pub fn mcast_querier_interval(&self) -> Option<u64>
Querier interval (centiseconds).
Sourcepub fn mcast_query_interval(&self) -> Option<u64>
pub fn mcast_query_interval(&self) -> Option<u64>
Query interval (centiseconds).
Sourcepub fn mcast_query_response_interval(&self) -> Option<u64>
pub fn mcast_query_response_interval(&self) -> Option<u64>
Query response interval (centiseconds).
Sourcepub fn mcast_startup_query_interval(&self) -> Option<u64>
pub fn mcast_startup_query_interval(&self) -> Option<u64>
Startup query interval (centiseconds).